@@ -11,8 +11,8 @@ use strict;
 use warnings;
 
 package CPANPLUS::Dist::Mageia;
-# ABSTRACT: a cpanplus backend to build mageia rpms
-$CPANPLUS::Dist::Mageia::VERSION = '2.102';
+# ABSTRACT: A CPANPLUS backend to build Mageia RPMs
+$CPANPLUS::Dist::Mageia::VERSION = '2.103';
 use base 'CPANPLUS::Dist::Base';
 
 use CPANPLUS::Error; # imported subs: error(), msg()
@@ -115,14 +115,18 @@ sub prepare {
     my $distdescr      = _module_description($module);
     #my $distlicense    =
     my ($disttoplevel) = $module->name=~ /([^:]+)::/;
-    my @reqs           = sort keys %{ $module->status->prereqs };
+    my @reqs           = sort { $a cmp $b} (
+        keys(%{ $module->status->prereqs }),
+        keys(%{ $self->find_configure_requires }),
+    );
+
 
     my ($distbuild, $distmaker, $distinstall);
     if (-e _path_to_makefile_pl($module)) {
         push @reqs, 'Module::Build::Compat' if _is_module_build_compat($module);
         $distbuild = "%{__perl} Makefile.PL INSTALLDIRS=vendor\n";
         $distmaker = "%make";
-        $distinstall = "%makeinstall_std";
+        $distinstall = "%make_install";
     } else {
         # module::build only distribution
         # The double dashes ("--") are for Module::Build::Tiny compatibility:
@@ -520,26 +524,30 @@ __END__
 
 =head1 NAME
 
-CPANPLUS::Dist::Mageia - a cpanplus backend to build mageia rpms
+CPANPLUS::Dist::Mageia - A CPANPLUS backend to build Mageia RPMs
 
 =head1 VERSION
 
-version 2.102
+version 2.103
+
+=head1 SYNOPSIS
+
+    $ cpan2dist --format=CPANPLUS::Dist::Mageia Some::Random::Package
 
 =head1 DESCRIPTION
 
-CPANPLUS::Dist::Mageia is a distribution class to create mageia packages
-from CPAN modules, and all its dependencies. This allows you to have
+CPANPLUS::Dist::Mageia is a distribution class to create Mageia packages
+from CPAN modules, and all of their dependencies. This allows you to have
 the most recent copies of CPAN modules installed, using your package
 manager of choice, but without having to wait for central repositories
 to be updated.
 
 You can either install them using the API provided in this package, or
-manually via rpm.
+manually via the C<rpm> command.
 
 Some of the bleading edge CPAN modules have already been turned into
-mageia packages for you, and you can make use of them by adding the
-cooker repositories (main & contrib).
+Mageia packages for you, and you can make use of them by adding the
+Cauldron repositories (“core/release”).
 
 Note that these packages are built automatically from CPAN and are
 assumed to have the same license as perl and come without support.
@@ -552,8 +560,8 @@ Please always refer to the original CPAN package if you have questions.
 Return a boolean indicating whether or not you can use this package to
 create and install modules in your environment.
 
-It will verify if you are on a mageia system, and if you have all the
-necessary components avialable to build your own mageia packages. You
+It will verify if you are on a Mageia system, and if you have all the
+necessary components avialable to build your own Mageia packages. You
 will need at least these dependencies installed: C<rpm>, C<rpmbuild> and
 C<gcc>.
 
@@ -566,23 +574,23 @@ Called automatically whenever you create a new C<CPANPLUS::Dist> object.
 
 =head2 my $bool = $mga->prepare;
 
-Prepares a distribution for creation. This means it will create the rpm
-spec file needed to build the rpm and source rpm. This will also satisfy
+Prepares a distribution for creation. This means it will create the RPM
+C<.spec> file needed to build the RPM and source RPM. This will also satisfy
 any prerequisites the module may have.
 
-Note that the spec file will be as accurate as possible. However, some
-fields may wrong (especially the description, and maybe the summary)
-since it relies on pod parsing to find those information.
+Note that the .spec file will be as accurate as possible. However, some
+fields may be wrong (especially the description, and maybe the summary)
+since it relies on parsing POD to find this information.
 
 Returns true on success and false on failure.
 
-You may then call C<< $mga->create >> on the object to create the rpm
+You may then call C<< $mga->create >> on the object to create the RPM
 from the spec file, and then C<< $mga->install >> on the object to
 actually install it.
 
 =head2 my $bool = $mga->create;
 
-Builds the rpm file from the spec file created during the C<create()>
+Builds the RPM file from the spec file created during the C<create()>
 step.
 
 Returns true on success and false on failure.
@@ -591,16 +599,12 @@ You may then call C<< $mga->install >> on the object to actually install it.
 
 =head2 my $bool = $mga->install;
 
-Installs the rpm using C<rpm -U>. If run as a non-root user, uses
+Installs the RPM using C<rpm -U>. If run as a non-root user, uses
 C<sudo>. This assumes that current user has sudo rights (without
 password for max efficiency) to run C<rpm>.
 
 Returns true on success and false on failure
 
-=head1 SYNOPSYS
-
-    $ cpan2dist --format=CPANPLUS::Dist::Mageia Some::Random::Package
-
 =head1 TODO
 
 =head2 Scan for proper license
@@ -611,8 +615,8 @@ really be probed rather than assumed.
 
 =head2 Long description
 
-Right now we provided the description as given by the module in it's
-meta data. However, not all modules provide this meta data and rather
+Right now we provide the description as given by the module in its
+meta-data. However, not all modules provide this meta-data and rather
 than scanning the files in the package for it, we simply default to the
 name of the module.
 
